==> savane-1.0.7+4.tar.gz: savane-1.0.7+4/frontend/php/people/viewgpg.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: viewgpg.php,v 1.15 2005/06/28 09:36:26 toddy Exp $
#
#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
#
# This program is free software; you can reprintdistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

if ($user_id)
{
  /*
		Fill in the info to create a job
  */

  #for security, include group_id
  $sql="SELECT * FROM user WHERE user_id='$user_id'";
  $result=db_query($sql);
  if (!$result || db_numrows($result) < 1)
    {
      exit_error(_("User not found."));


    }
  else
    {
      print site_header(array('title'=>_("View a GPG Key"),
			      'toptab'=>'keys'));

      print '<h3>';
      $realname = db_result($result, 0, 'realname');
      if(!$realname) $realname = '';
      # I18N
      # The string is the realname and user_name, e.g "GPG key of John Doe <jdoe>"
      printf(_("GPG key of %s"), $realname.' &lt;'.db_result($result, 0, 'user_name').'&gt;');
      print '</h3>';

      if (!db_result($result,0,'gpg_key'))
	{
	  print '<p>'._("This user hasn't registered a GPG key.").'</p>';
	}
      else
	{
	  print '<div>'.nl2br(utils_make_links(db_result($result,0,'gpg_key'))).'</div>';
	}
    }

  print site_footer(array());

}
else
{
  /*
		Not logged in or insufficient privileges
  */
  exit_error(_("User not found."));
}

?>

==> savane-1.1.tar.gz: savane-1.1/frontend/php/people/viewgpg.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: viewgpg.php,v 1.17 2005/08/19 06:15:37 beuc Exp $
#
#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
#
# The Savane project is free software; you can reprintdistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


require "../include/pre.php";

if ($user_id)
{
  /*
		Fill in the info to create a job
  */

  #for security, include group_id
  $sql="SELECT * FROM user WHERE user_id='$user_id'";
  $result=db_query($sql);
  if (!$result || db_numrows($result) < 1)
    {
      exit_error(_("User not found."));


    }
  else
    {
      print site_header(array('title'=>_("View a GPG Key"),
			      'toptab'=>'keys'));

      print '<h3>';
      $realname = db_result($result, 0, 'realname');
      if(!$realname) $realname = '';
      # I18N
      # The string is the realname and user_name, e.g "GPG key of John Doe <jdoe>"
      printf(_("GPG key of %s"), $realname.' &lt;'.db_result($result, 0, 'user_name').'&gt;');
      print '</h3>';

      if (!db_result($result,0,'gpg_key'))
	{
	  print '<p>'._("This user hasn't registered a GPG key.").'</p>';
	}
      else
	{
	  print '<code>'.nl2br(utils_make_links(db_result($result,0,'gpg_key'))).'</code>';
	}
    }

  print site_footer(array());

}
else
{
  /*
		Not logged in or insufficient privileges
  */
  exit_error(_("User not found."));
}

?>
